CombinedMigrationSource

Struct CombinedMigrationSource 

pub struct CombinedMigrationSource<DB> { /* private fields */ }
A diesel migration source that combines several other sources

This source will act like all migrations came from a single source. It orders all the migrations by version

Example

use diesel::prelude::*;
use diesel_migrations::EmbeddedMigrations;
use diesel_migrations::CombinedMigrationSource;
use crate::diesel_migrations::MigrationHarness;
use migrations_macros::embed_migrations;

pub const PG_MIGRATIONS: EmbeddedMigrations = embed_migrations!("../migrations/postgres");
pub const SQLITE_MIGRATIONS: EmbeddedMigrations = embed_migrations!("../migrations/sqlite");

// Create a new empty combined source
let mut combined_sources = CombinedMigrationSource::default();

// It's not particular meaningful to combine PostgreSQL and SQLite like this,
// but that reasonable demonstrates the API
combined_sources.add_source(PG_MIGRATIONS);
combined_sources.add_source(SQLITE_MIGRATIONS);

// run the migrations
let mut connection = SqliteConnection::establish(&connection_url)?;
let res = connection.run_pending_migrations(combined_sources);

Implementations

Source

impl<DB> CombinedMigrationSource<DB>
where DB: Backend,

pub fn add_source( &mut self, source: impl MigrationSource<DB> + Send + Sync + 'static, )

Register another source with the given migration source