pub struct RustMigration<Conn> { /* private fields */ }Expand description
A rust side migration
This type represents a simple rust side migration builder that allows you to register a rust callback as up and down migration and that also allows you to customize the migration settings
Constructing a RustMigration requires to specify an up migration that
describes how to migrate your database schema from an old to an new version.
Down migrations, that describe how to revert the changes done by the up migrations, are optional. If you don’t plan to revert migrations you don’t need to provide them.
Implementations
Sourceimpl<Conn> RustMigration<Conn>
impl<Conn> RustMigration<Conn>
Sourcepub fn new(up: impl Fn(&mut Conn) -> QueryResult<()> + 'static) -> Self
pub fn new(up: impl Fn(&mut Conn) -> QueryResult<()> + 'static) -> Self
Construct a new instance of this type with a given up migration function.
This function needs to perform any action to migrate your database from an old version to the expected new version
Sourcepub fn with_down(
self,
down: impl Fn(&mut Conn) -> QueryResult<()> + 'static,
) -> Self
pub fn with_down( self, down: impl Fn(&mut Conn) -> QueryResult<()> + 'static, ) -> Self
Register a down migration
This function allows you to register a down migration to revert any changes done by the up migration. It is used to restore the database schema used before this migration was applied in the case of an revert. If you don’t plan to revert migrations you don’t need to provide a down migration.
Sourcepub fn without_transaction(self) -> Self
pub fn without_transaction(self) -> Self
Customizes the migration settings to not run this migration in a transaction
By default diesel will execute migrations inside of a transaction on all database systems supporting this to ensure that migrations are either fully executed or not.
Some database operations require to be run outside transactions. If you use such an operation in either your up or down migration you need to use this function to disable the default transaction behaviour.